var fs = require('fs'),
    consoleFileLogger = require("../sl-logger.js").consoleFileLogger,
    sourceMap = require("source-map");

function readSourceMaps(fullFilename, logger) {
    if (!fullFilename) return;
    var sourceMapsFilename = fullFilename + '.map';
    var contents, rawSourceMapJsonData, consumer;
    var log = logger ? logger.child({
        methodName: "readSourceMaps"
    }) : consoleFileLogger("readSourceMaps");
    try {
        contents = fs.readFileSync(sourceMapsFilename).toString();
    } catch (e) {
        //Sourcemap file not found
        return null;
    }

    try {
        rawSourceMapJsonData = JSON.parse(contents);
    } catch (e) {
        log.error('Ignoring invalid source map: ' + sourceMapsFilename);
        return null;
    }

    try {
        log.debug('Processing source maps from file: ' + sourceMapsFilename);
        consumer = new sourceMap.SourceMapConsumer(rawSourceMapJsonData);
        return consumer;
    } catch (e) {
        log.error('Error processing source maps for file: ' + sourceMapsFilename);
        return null;
    }
}

function ActualFile(filename, fullFilename) {
    this.getFilename = function ActualFile$getFilename() {
        return filename;
    }
    this.getFullFilename = function ActualFile$getFullFilename() {
        return fullFilename;
    }
    this.getContent = function ActualFile$getContent() {
        var content = fs.readFileSync(fullFilename, 'utf-8');
        return content;
    }
    this.readSourceMaps = function ActualFile$readSourceMaps(logger) {
        return readSourceMaps(fullFilename, logger);
    }
}
module.exports = ActualFile;